@@ -15,6 +15,7 @@
 #include "fieldview.h"
 #include "infopanel.h"
 #include "modepanel.h"
+#include "scorepanel.h"
 #include "serverdialog.h"
 #include "clientdialog.h"
 #include "protocol.h"
@@ -44,15 +45,17 @@ CentralWidget::CentralWidget(QWidget *parent, ReversiGame &reversiGame):
 
     modePanel_ = new ModePanel(this, settings_.mode(), settings_.AILevel());
     infoLayout_->addWidget(modePanel_);
+
+    scorePanel_ = new ScorePanel(this);
+    infoLayout_->addWidget(scorePanel_);
     infoLayout_->addStretch(1);
 
     layout_->addItem(infoLayout_, 0, 1);
 
-
-
     showInfoPanels();
 
     connect(&reversiGame_, SIGNAL(stepUnavailable()), SLOT(stepUnavailable()));
+    connect(&reversiGame_, SIGNAL(gameOver()), SLOT(slotGameOver()));
 
     //network stuff
     gameServer_ = new QTcpServer(this);
@@ -111,6 +114,16 @@ CentralWidget::newGame()
     }
     isNetworkGame_ = mode.first > 2;
     reversiGame_.init(gameMode_, strength_, isNetworkGame_);
+
+    if (mode.first == 1 || mode.first == 2)
+    {
+        unsigned w, l, d;
+        score_.score(mode.second, &w, &l, &d);
+        scorePanel_->setScore(w, l, d);
+        scorePanel_->show();
+    }
+    else
+        scorePanel_->hide();
 }//newGame
 
 bool CentralWidget::newGameP2PServer()
@@ -288,3 +301,31 @@ void CentralWidget::slotOptions()
     if (optDlg.exec() == QDialog::Accepted)
         fieldView_->setAnimationSpeed(settings_.animationSpeed());
 }
+
+void CentralWidget::slotGameOver()
+{
+    QString info;
+    unsigned white_score = reversiGame_.score(White);
+    unsigned black_score = reversiGame_.score(Black);
+    info = QString(tr("Game over!\n White player %1; Black player %2.")).arg(white_score).arg(black_score);
+    showMessage(parentWidget(), info);
+
+    QPair<int, int> mode = modePanel_->mode();
+    if (mode.first == 1 || mode.first == 2) //human vs comp or comp vs human
+    {
+        Score::score_type s_type = Score::DRAW;
+        if (black_score != white_score)
+        {
+            if (mode.first == 1)
+                s_type = (black_score > white_score) ? Score::WIN : Score::LOSS;
+            else
+                s_type = (black_score < white_score) ? Score::WIN : Score::LOSS;
+        }
+        score_.incScore(mode.second, s_type);
+        unsigned w, l, d;
+        score_.score(mode.second, &w, &l, &d);
+        scorePanel_->setScore(w, l, d);
+    }//if (mode.first == 1 || mode.first == 2)
+    if (settings_.startNewGame())
+        newGame();
+}
