@@ -6,6 +6,7 @@
 
 #include "reversigame.h"
 #include "qthellosettings.h"
+#include "score.h"
 
 enum P2PSTATE {WAIT_SERVER_VERSION, WAIT_CLIENT_VERSION, WAIT_SERVER_NEW_GAME, RUNNING, SERVER_PAUSED, CLIENT_PAUSED};
 
@@ -16,6 +17,7 @@ class QTcpSocket;
 class FieldView;
 class InfoPanel;
 class ModePanel;
+class ScorePanel;
 
 class CentralWidget : public QWidget
 {
@@ -40,12 +42,14 @@ private:
     FieldView *fieldView_;
     InfoPanel *infoPanel_;
     ModePanel *modePanel_;
+    ScorePanel *scorePanel_;
     int gameMode_;
     P2PSTATE P2PState_;
     int strength_;
     bool isNetworkGame_;
 
     ReversiGame &reversiGame_;
+    Score       score_;
 
     QthelloSettings settings_;
 
@@ -54,6 +58,7 @@ public slots:
      * @brief Starts new game
      */
     void newGame();
+    void slotGameOver();
     void slotPlayerStep(int x, int y);
     void slotOptions();
 
