@@ -31,3 +31,7 @@ QSize FieldView::sizeHint () const
 {
     return QSize(scene_->fieldWidth(), scene_->fieldHeight());
 }
+void FieldView::setAnimationSpeed(int animationSpeed)
+{
+    scene_->setAnimationSpeed(animationSpeed);
+}
