@@ -44,7 +44,7 @@ InfoPanel::InfoPanel(const ReversiGame &reversiGame, QWidget *parent) :
     setLayout(layout);
 
     connect(&reversiGame_, SIGNAL(updateInfo()), this, SLOT(slotStepComplete()) );
-    connect(&reversiGame_, SIGNAL(newGame(bool)), this, SLOT(slotStepComplete()) );
+    connect(&reversiGame_, SIGNAL(newGame(int)), this, SLOT(slotStepComplete()) );
 }
 
 void InfoPanel::setInfo()
