@@ -27,7 +27,6 @@ MainWindow::MainWindow(QWidget *parent)
 #endif
 
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(slotOrientationChanged()));
-    connect(&reversiGame_, SIGNAL(gameOver()), SLOT(slotGameOver()));
     slotNewGame();
 }
 
@@ -62,14 +61,6 @@ void MainWindow::slotNewGame()
     centralWdgt->newGame();
 }
 
-void MainWindow::slotGameOver()
-{
-    QString info;
-    info = QString(tr("Game over!\n White player %1; Black player %2.")).arg(reversiGame_.score(White)).arg(reversiGame_.score(Black));
-    showMessage(this, info);
-    slotNewGame();
-}
-
 void MainWindow::slotOrientationChanged()
 {
     centralWdgt->showInfoPanels();
