@@ -5,7 +5,7 @@
 
 #include "modepanel.h"
 
-ModePanel::ModePanel(QWidget *parent) :
+ModePanel::ModePanel(QWidget *parent, int defaultMode, int defaultAILevel) :
     QWidget(parent)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
@@ -23,23 +23,22 @@ ModePanel::ModePanel(QWidget *parent) :
     cbMode_->addItem(tr("Computer vs human"));
     cbMode_->addItem(tr("Net (server)"));
     cbMode_->addItem(tr("Net (client)"));
-    cbMode_->setCurrentIndex(1);
+    cbMode_->setCurrentIndex(defaultMode);
     hlayout->addWidget(cbMode_, 0, 1);
 
     cbStrength_ = new QComboBox(this);
-    //cbStrength_->addItem(tr("Very easy"));
     cbStrength_->addItem(tr("Easy"));
     cbStrength_->addItem(tr("Medium"));
     cbStrength_->addItem(tr("Hard"));
-    //cbStrength_->addItem(tr("Very hard"));
-    //cbStrength_->addItem(tr("Extremely hard"));
-    //cbStrength_->addItem(tr("Impossible"));
     cbStrength_->addItem(tr("Expert"));
-    cbStrength_->setCurrentIndex(1);
+    cbStrength_->setCurrentIndex(defaultAILevel);
     hlayout->addWidget(cbStrength_, 1, 1);
 
     layout->addItem(hlayout);
     setLayout(layout);
+
+    connect(cbMode_, SIGNAL(currentIndexChanged(int)), parent, SLOT(newGame()));
+    connect(cbStrength_, SIGNAL(currentIndexChanged(int)), parent, SLOT(newGame()));
 }
 
 QPair<int, int>
