@@ -4,88 +4,95 @@
 <context>
     <name>CentralWidget</name>
     <message>
-        <location filename="centralwidget.cpp" line="121"/>
+        <location filename="centralwidget.cpp" line="134"/>
         <source>Error!!
 Unable to start the game server: %1.</source>
         <translation>Ошибка!!
 Невозможо запустить сервер: %1.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="197"/>
+        <location filename="centralwidget.cpp" line="210"/>
         <source>Warning!
 Wait answer from client.</source>
         <translation>Внимание!
 Ожидание ответа от клиента.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="200"/>
+        <location filename="centralwidget.cpp" line="213"/>
         <source>Warning!
 Client is paused.</source>
         <translation>Внимание!!
 Клиент приостановлен.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="203"/>
+        <location filename="centralwidget.cpp" line="216"/>
         <source>Warning!
 Server is paused.</source>
         <translation>Внимание!!
 Сервер приостановлен.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="207"/>
+        <location filename="centralwidget.cpp" line="220"/>
         <source>Warning!
 Wait answer from server.</source>
         <translation>Внимание!
 Ожидание ответа от сервера.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="215"/>
+        <location filename="centralwidget.cpp" line="228"/>
         <source>Warning!
 It&apos;s White player turn now.</source>
         <translation>Внимание!!
 Ход белых.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="220"/>
+        <location filename="centralwidget.cpp" line="233"/>
         <source>Warning!
 It&apos;s Black player turn now.</source>
         <translation>Внимание!!
 Ход черных.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="234"/>
+        <location filename="centralwidget.cpp" line="247"/>
         <source>White</source>
         <translation>Белые</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="234"/>
+        <location filename="centralwidget.cpp" line="247"/>
         <source>Black</source>
         <translation>Черные</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="236"/>
+        <location filename="centralwidget.cpp" line="249"/>
         <source>%1 can&apos;t move. %2 turn.</source>
         <translation>%1 не могут ходить. %2 ходят.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="271"/>
+        <location filename="centralwidget.cpp" line="284"/>
         <source>Warning!
 The host was not found.</source>
         <translation>Внимание!
 Хост не найден.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="274"/>
+        <location filename="centralwidget.cpp" line="287"/>
         <source>Warning!
 The connection was refused by the peer.</source>
         <translation>Внимание!
 Соединение отброшено противополжной стороной.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="277"/>
+        <location filename="centralwidget.cpp" line="290"/>
         <source>The following error occurred: %1.</source>
         <translation>Возникла ошибка: %1.</translation>
     </message>
+    <message>
+        <location filename="centralwidget.cpp" line="310"/>
+        <source>Game over!
+ White player %1; Black player %2.</source>
+        <translation>Игра окончена!
+Белые %1; Черные %2.</translation>
+    </message>
 </context>
 <context>
     <name>ClientDialog</name>
@@ -151,45 +158,44 @@ The connection was refused by the peer.</source>
         <translation>Qthello</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="41"/>
+        <location filename="mainwindow.cpp" line="40"/>
         <source>&amp;Game</source>
         <translation>&amp;Игра</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="42"/>
+        <location filename="mainwindow.cpp" line="41"/>
         <source>&amp;New game</source>
         <translation>&amp;Новая игра</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="47"/>
+        <location filename="mainwindow.cpp" line="46"/>
         <source>E&amp;xit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="51"/>
+        <location filename="mainwindow.cpp" line="50"/>
         <source>&amp;Options</source>
         <translation>&amp;Параметры</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="52"/>
+        <location filename="mainwindow.cpp" line="51"/>
         <source>&amp;Options...</source>
         <translation>&amp;Параметры...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="55"/>
+        <location filename="mainwindow.cpp" line="54"/>
         <source>&amp;Help</source>
         <translation>&amp;Помощь</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="56"/>
+        <location filename="mainwindow.cpp" line="55"/>
         <source>&amp;About...</source>
         <translation>&amp;О программе...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="68"/>
         <source>Game over!
  White player %1; Black player %2.</source>
-        <translation>Игра окончена!
+        <translation type="obsolete">Игра окончена!
 Белые %1; Черные %2.</translation>
     </message>
     <message>
@@ -205,12 +211,12 @@ The connection was refused by the peer.</source>
         <translation type="obsolete">%1 не могут ходить. %2 ходят.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="80"/>
+        <location filename="mainwindow.cpp" line="71"/>
         <source>About Qthello</source>
         <translation>Про Qthello</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="80"/>
+        <location filename="mainwindow.cpp" line="71"/>
         <source>Othello/Reversi game
 
 General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;
@@ -317,6 +323,29 @@ AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
         <source>&amp;Save mode on exit</source>
         <translation>&amp;Сохраять режим при выходе</translation>
     </message>
+    <message>
+        <location filename="optionsdialog.cpp" line="31"/>
+        <source>Start new game automatically</source>
+        <translation>Запускать новую игру автоматом</translation>
+    </message>
+</context>
+<context>
+    <name>ScorePanel</name>
+    <message>
+        <location filename="scorepanel.cpp" line="10"/>
+        <source>Won</source>
+        <translation>Побед</translation>
+    </message>
+    <message>
+        <location filename="scorepanel.cpp" line="12"/>
+        <source>Lost</source>
+        <translation>Пораж.</translation>
+    </message>
+    <message>
+        <location filename="scorepanel.cpp" line="14"/>
+        <source>Drawn</source>
+        <translation>Ничьих</translation>
+    </message>
 </context>
 <context>
     <name>ServerDialog</name>
