@@ -4,86 +4,92 @@
 <context>
     <name>CentralWidget</name>
     <message>
-        <location filename="centralwidget.cpp" line="121"/>
+        <location filename="centralwidget.cpp" line="134"/>
         <source>Error!!
 Unable to start the game server: %1.</source>
         <translation>Помилка!!
 Неможливо запустити сервер: %1.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="197"/>
+        <location filename="centralwidget.cpp" line="210"/>
         <source>Warning!
 Wait answer from client.</source>
         <translation>Увага!
 Очiкування вiвдповiдi вiд клiєнта.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="200"/>
+        <location filename="centralwidget.cpp" line="213"/>
         <source>Warning!
 Client is paused.</source>
         <translation>Увага!
 Клiєнт призупинено.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="203"/>
+        <location filename="centralwidget.cpp" line="216"/>
         <source>Warning!
 Server is paused.</source>
         <translation>Увага!
 Сервер призупинено.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="207"/>
+        <location filename="centralwidget.cpp" line="220"/>
         <source>Warning!
 Wait answer from server.</source>
         <translation>Увага!
 Очiкування вiвдповiдi вiд сервера.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="215"/>
+        <location filename="centralwidget.cpp" line="228"/>
         <source>Warning!
 It&apos;s White player turn now.</source>
         <translation>Увага!
 Зараз ходять бiлi.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="220"/>
+        <location filename="centralwidget.cpp" line="233"/>
         <source>Warning!
 It&apos;s Black player turn now.</source>
         <translation>Увага!
 Зараз ходять чорнi.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="234"/>
+        <location filename="centralwidget.cpp" line="247"/>
         <source>White</source>
         <translation>Бiлi</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="234"/>
+        <location filename="centralwidget.cpp" line="247"/>
         <source>Black</source>
         <translation>Чорнi</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="236"/>
+        <location filename="centralwidget.cpp" line="249"/>
         <source>%1 can&apos;t move. %2 turn.</source>
         <translation>%1 не можуть ходити. %2 ходять.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="271"/>
+        <location filename="centralwidget.cpp" line="284"/>
         <source>Warning!
 The host was not found.</source>
         <translation>Увага! Хост не знайдено.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="274"/>
+        <location filename="centralwidget.cpp" line="287"/>
         <source>Warning!
 The connection was refused by the peer.</source>
         <translation>Увага! З&apos;єднання вiдхилено протилежною стороною.</translation>
     </message>
     <message>
-        <location filename="centralwidget.cpp" line="277"/>
+        <location filename="centralwidget.cpp" line="290"/>
         <source>The following error occurred: %1.</source>
         <translation>Трапилась помилка: %1.</translation>
     </message>
+    <message>
+        <location filename="centralwidget.cpp" line="310"/>
+        <source>Game over!
+ White player %1; Black player %2.</source>
+        <translation>Гру завершено! Бiлi %1; Чорнi %2.</translation>
+    </message>
 </context>
 <context>
     <name>ClientDialog</name>
@@ -149,45 +155,44 @@ The connection was refused by the peer.</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="41"/>
+        <location filename="mainwindow.cpp" line="40"/>
         <source>&amp;Game</source>
         <translation>&amp;Гра</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="42"/>
+        <location filename="mainwindow.cpp" line="41"/>
         <source>&amp;New game</source>
         <translation>&amp;Нова гра</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="47"/>
+        <location filename="mainwindow.cpp" line="46"/>
         <source>E&amp;xit</source>
         <translation>&amp;Вихiд</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="51"/>
+        <location filename="mainwindow.cpp" line="50"/>
         <source>&amp;Options</source>
         <translation>&amp;Параметри</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="52"/>
+        <location filename="mainwindow.cpp" line="51"/>
         <source>&amp;Options...</source>
         <translation>&amp;Параметри...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="55"/>
+        <location filename="mainwindow.cpp" line="54"/>
         <source>&amp;Help</source>
         <translation>&amp;Допомога</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="56"/>
+        <location filename="mainwindow.cpp" line="55"/>
         <source>&amp;About...</source>
         <translation>&amp;Про програму...</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="68"/>
         <source>Game over!
  White player %1; Black player %2.</source>
-        <translation>Гру завершено! Бiлi %1; Чорнi %2.</translation>
+        <translation type="obsolete">Гру завершено! Бiлi %1; Чорнi %2.</translation>
     </message>
     <message>
         <source>White</source>
@@ -202,12 +207,12 @@ The connection was refused by the peer.</source>
         <translation type="obsolete">%1 не можуть ходити. %2 ходять.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="80"/>
+        <location filename="mainwindow.cpp" line="71"/>
         <source>About Qthello</source>
         <translation>Про Отелло</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="80"/>
+        <location filename="mainwindow.cpp" line="71"/>
         <source>Othello/Reversi game
 
 General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;
@@ -299,17 +304,17 @@ AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
     <message>
         <location filename="optionsdialog.cpp" line="17"/>
         <source>Animation speed:</source>
-        <translation>Швідкисть анімації:</translation>
+        <translation>Швiдкисть анiмацiї:</translation>
     </message>
     <message>
         <location filename="optionsdialog.cpp" line="20"/>
         <source>No animation</source>
-        <translation>Без анімації</translation>
+        <translation>Без анiмацiї</translation>
     </message>
     <message>
         <location filename="optionsdialog.cpp" line="21"/>
         <source>Slow</source>
-        <translation>Повільно</translation>
+        <translation>Повiльно</translation>
     </message>
     <message>
         <location filename="optionsdialog.cpp" line="22"/>
@@ -324,7 +329,30 @@ AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
     <message>
         <location filename="optionsdialog.cpp" line="27"/>
         <source>&amp;Save mode on exit</source>
-        <translation>&amp;Зебрігати режим при виході</translation>
+        <translation>&amp;Зберiгати режим при виходi</translation>
+    </message>
+    <message>
+        <location filename="optionsdialog.cpp" line="31"/>
+        <source>Start new game automatically</source>
+        <translation>Автоматично статувати нову гру</translation>
+    </message>
+</context>
+<context>
+    <name>ScorePanel</name>
+    <message>
+        <location filename="scorepanel.cpp" line="10"/>
+        <source>Won</source>
+        <translation>Перемог</translation>
+    </message>
+    <message>
+        <location filename="scorepanel.cpp" line="12"/>
+        <source>Lost</source>
+        <translation>Поразок</translation>
+    </message>
+    <message>
+        <location filename="scorepanel.cpp" line="14"/>
+        <source>Drawn</source>
+        <translation>Нiчiїх</translation>
     </message>
 </context>
 <context>
