@@ -5,6 +5,7 @@
 QthelloSettings::QthelloSettings()
 {
     QSettings settings;
+    startNewGame_ = settings.value("StartNewGame", true).toBool();
     animationSpeed_ = settings.value("AnimationSpeed", 2).toInt();
     saveMode_ = settings.value("SaveMode", true).toBool();
     if (saveMode_)
@@ -22,6 +23,7 @@ QthelloSettings::QthelloSettings()
 QthelloSettings::~QthelloSettings()
 {
     QSettings settings;
+    settings.setValue("StartNewGame", startNewGame_);
     settings.setValue("AnimationSpeed", animationSpeed_);
     settings.setValue("SaveMode", saveMode_);
     if (saveMode_)
