@@ -14,8 +14,7 @@
 #include "pixmaps/c09.xpm"
 #include "pixmaps/c10.xpm"
 
-ReversiItem::ReversiItem(QGraphicsScene *scene):
-        QGraphicsPixmapItem(0, scene)
+PixmapsFactory::PixmapsFactory()
 {
     chipPixmaps_[White] = QPixmap(WhiteCell_xpm);
     chipPixmaps_[Black] = QPixmap(BlackCell_xpm);
@@ -30,11 +29,16 @@ ReversiItem::ReversiItem(QGraphicsScene *scene):
     chipPixmaps_[10] = QPixmap(c08_xpm);
     chipPixmaps_[11] = QPixmap(c09_xpm);
     chipPixmaps_[12] = QPixmap(c10_xpm);
+}
 
+ReversiItem::ReversiItem(QGraphicsScene *scene, PixmapsFactory *pixmapsFactory):
+        QGraphicsPixmapItem(0, scene),
+        pixmapsFactory_(pixmapsFactory)
+{
     setColor(Empty);
 }
 
 void ReversiItem::setColor(int c)
 {
-    setPixmap(chipPixmaps_[c]);
+    setPixmap(pixmapsFactory_->chipPixmaps_[c]);
 }
