@@ -111,7 +111,7 @@ void ReversiScene::slotStepComplete()
     update(x * cellWidth_, y * cellHeight_, cellWidth_, cellHeight_);
 
     //start animation
-    animTimer_->start(50);
+    animTimer_->start(animationSpeed_);
 }//slotStepComplete
 
 void ReversiScene::slotAnimationStep()
@@ -152,3 +152,17 @@ void ReversiScene::slotAnimationStep()
     reversiGame_.startNextTurn();
     }
 } //slotAnimationStep
+
+void ReversiScene::setAnimationSpeed(int animationSpeed)
+{
+    static int timerSpeed[] = {1, 100, 50, 25};
+    if (animationSpeed >=0 && animationSpeed < sizeof(timerSpeed))
+        animationSpeed_ = timerSpeed[animationSpeed];
+    else
+        animationSpeed_ = 50;
+    if (animTimer_->isActive())
+    {
+        animTimer_->stop();
+        animTimer_->start(animationSpeed_);
+    }
+}
