@@ -20,6 +20,7 @@ public:
     int fieldWidth() const { return fieldWidth_; }
     int fieldHeight() const { return fieldHeight_; }
     void setIsNetworkMode(bool mode) { isNetworkMode_ = mode;}
+    void setAnimationSpeed(int animationSpeed);
 
 public slots:
     void syncBoard();
@@ -47,6 +48,7 @@ private:
     int fieldHeight_;
     bool isNetworkMode_;
     int mode_;
+    int animationSpeed_;
 
     //variables for animation
     QTimer *animTimer_;
